@@ -3,7 +3,7 @@ from textflow.model.annotation import AnnotationSet, Annotation, AnnotationSpan
 from textflow.model.dataset import Dataset, datasets
 from textflow.model.document import Document
 from textflow.model.label import Label
-from textflow.model.model import models
+from textflow.model.estimator import estimators
 from textflow.model.project import Project
 from textflow.model.user import Assignment, User
 
@@ -18,5 +18,5 @@ __all__ = [
     'User',
     'Dataset',
     'datasets',
-    'models',
+    'estimators',
 ]
