@@ -1,6 +1,6 @@
 """ Annotation Entity """
 
-from textflow.service.base import database as db
+from textflow.services.base import database as db
 
 
 class AnnotationSpan(db.Model):
@@ -39,28 +39,44 @@ class Annotation(db.Model):
         return self.span.slice()
 
 
+class AnnotationSetLog(db.Model):
+    """ Annotation-Span Entity - contains start and length """
+    id = db.Column(db.Integer, primary_key=True)
+    annotation_id = db.Column(db.Integer, db.ForeignKey('annotation_set.id'), nullable=False)
+    flagged = db.Column(db.Boolean(), nullable=False, default=False)
+    skipped = db.Column(db.Boolean(), nullable=False, default=False)
+    completed = db.Column(db.Boolean(), nullable=False, default=False)
+    created_on = db.Column(db.DateTime, server_default=db.func.now())
+    updated_on = db.Column(db.DateTime, server_default=db.func.now(), server_onupdate=db.func.now())
+
+
 class AnnotationSet(db.Model):
     """ AnnotationSet Entity - contains annotations by a user for a document. """
     id = db.Column(db.Integer, primary_key=True)
-    document_id = db.Column(db.Integer, db.ForeignKey('document.id'), nullable=False)
+    document_id = db.Column(db.Integer, db.ForeignKey('document.id', ondelete="CASCADE"), nullable=False)
     document = db.relationship('Document', backref=db.backref('annotation_set', lazy=True, cascade="all,delete"),
                                uselist=False)
     user_id = db.Column(db.Integer, db.ForeignKey('user.id'), nullable=False)
     user = db.relationship('User', backref=db.backref('annotation_set', lazy=True), uselist=False)
     annotations = db.relationship('Annotation', backref='annotation_set', lazy=True, cascade='all, delete')
     completed = db.Column(db.Boolean(), nullable=False, default=False)
+    flagged = db.Column(db.Boolean(), nullable=False, default=False)
+    skipped = db.Column(db.Boolean(), nullable=False, default=False)
     created_on = db.Column(db.DateTime, server_default=db.func.now())
     updated_on = db.Column(db.DateTime, server_default=db.func.now(), server_onupdate=db.func.now())
 
+    logger = db.relationship('AnnotationSetLog', backref='annotation_set', lazy=True, cascade='all, delete')
+
     __table_args__ = (db.UniqueConstraint('user_id', 'document_id'),)
 
-    def get_annotation(self, value):
-        """ gets annotations with the value from the annotations
 
-        :param value: value of label to search
-        :return: annotation with provided value if exists other wise none
-        """
-        for a in self.annotations:
-            if a.label.value == value:
-                return a
-        return None
+@db.event.listens_for(AnnotationSet, 'after_insert')
+@db.event.listens_for(AnnotationSet, 'after_update')
+def log_update_event(mapper, connection, target):
+    log = AnnotationSetLog(annotation_id=target.id)
+    log.document_id = target.document_id
+    log.user_id = target.user_id
+    log.completed = target.completed
+    log.flagged = target.flagged
+    log.skipped = target.skipped
+    db.session.add(log)
